@@ -15,12 +15,13 @@ Usage::
 from typing import IO, Any, Dict, Type, Union
 
 from botocore.client import ClientMeta
+from botocore.response import StreamingBody
 
 from .type_defs import (
-    DeleteThingShadowResponseTypeDef,
-    GetThingShadowResponseTypeDef,
-    ListNamedShadowsForThingResponseTypeDef,
-    UpdateThingShadowResponseTypeDef,
+    DeleteThingShadowResponseResponseTypeDef,
+    GetThingShadowResponseResponseTypeDef,
+    ListNamedShadowsForThingResponseResponseTypeDef,
+    UpdateThingShadowResponseResponseTypeDef,
 )
 
 __all__ = ("IoTDataPlaneClient",)
@@ -50,7 +51,7 @@ class Exceptions:
 
 class IoTDataPlaneClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/iot-data.html#IoTDataPlane.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/iot-data.html#IoTDataPlane.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html)
     """
 
@@ -59,15 +60,19 @@ class IoTDataPlaneClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/iot-data.html#IoTDataPlane.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/iot-data.html#IoTDataPlane.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#can_paginate)
         """
 
     def delete_thing_shadow(
         self, *, thingName: str, shadowName: str = None
-    ) -> DeleteThingShadowResponseTypeDef:
+    ) -> DeleteThingShadowResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/iot-data.html#IoTDataPlane.Client.delete_thing_shadow)
+        Deletes the shadow for the specified thing.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/iot-data.html#IoTDataPlane.Client.delete_thing_shadow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#delete_thing_shadow)
         """
 
@@ -79,38 +84,52 @@ class IoTDataPlaneClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/iot-data.html#IoTDataPlane.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/iot-data.html#IoTDataPlane.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#generate_presigned_url)
         """
 
     def get_thing_shadow(
         self, *, thingName: str, shadowName: str = None
-    ) -> GetThingShadowResponseTypeDef:
+    ) -> GetThingShadowResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/iot-data.html#IoTDataPlane.Client.get_thing_shadow)
+        Gets the shadow for the specified thing.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/iot-data.html#IoTDataPlane.Client.get_thing_shadow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#get_thing_shadow)
         """
 
     def list_named_shadows_for_thing(
         self, *, thingName: str, nextToken: str = None, pageSize: int = None
-    ) -> ListNamedShadowsForThingResponseTypeDef:
+    ) -> ListNamedShadowsForThingResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/iot-data.html#IoTDataPlane.Client.list_named_shadows_for_thing)
+        Lists the shadows for the specified thing.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/iot-data.html#IoTDataPlane.Client.list_named_shadows_for_thing)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#list_named_shadows_for_thing)
         """
 
     def publish(
-        self, *, topic: str, qos: int = None, payload: Union[bytes, IO[bytes]] = None
+        self, *, topic: str, qos: int = None, payload: Union[bytes, IO[bytes], StreamingBody] = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/iot-data.html#IoTDataPlane.Client.publish)
+        Publishes state information.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/iot-data.html#IoTDataPlane.Client.publish)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#publish)
         """
 
     def update_thing_shadow(
-        self, *, thingName: str, payload: Union[bytes, IO[bytes]], shadowName: str = None
-    ) -> UpdateThingShadowResponseTypeDef:
+        self,
+        *,
+        thingName: str,
+        payload: Union[bytes, IO[bytes], StreamingBody],
+        shadowName: str = None
+    ) -> UpdateThingShadowResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/iot-data.html#IoTDataPlane.Client.update_thing_shadow)
+        Updates the shadow for the specified thing.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/iot-data.html#IoTDataPlane.Client.update_thing_shadow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#update_thing_shadow)
         """
